<?php
/*
Plugin Name: Easy Chart Builder
Version: 0.4
Plugin URI: http://www.dyerware.com/main/easy-chart-builder
Description: Creates a chart directly in your post or page via shortcut.  Manages sizing of chart to support wptouch and other mobile themes.
Author: dyerware
Author URI: http://www.dyerware.com
*/
/*  Copyright © 2009  dyerware
    Support: support@dyerware.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
  
class wpEasyCharts
{
    private $chartNum = 0;
    
	public function __construct()
    {   
        $jsDir = get_option('siteurl') . '/wp-content/plugins/easy-chart-builder/js/';
        wp_register_script('wpEasyCharts', "{$jsDir}easy-chart-builder.js", false, '0.4');       
    }

	function addCSS() 
	{
	   
		echo '<link type="text/css" rel="stylesheet" href="' . plugins_url ( plugin_basename ( dirname ( __FILE__ ) ) ) .'/easy-chart-builder.css" />';
		
	
	}
	
	public function output_scripts ()
    {
        
       wp_enqueue_script('wpEasyCharts');
        
    }
 
    private function translateNumerics(&$value, $key) {
        
        if ($value == 'false') {
        	$value = false;
        } elseif ($value == 'true') {
            $value = true;
        }
        
    }        
            
	public function process_shortcode($atts, $content=null, $code="") 
	{  
	   	$haveIssue = FALSE;
	    $nearKey = "";
	    $nearValue = "";
	    
	    foreach ($atts as $key => $att)
	    {
	       $keyval = (int)$key;
	       if ($keyval != 0 || strpos($key, "0") === 0)
	       {
                $haveIssue = TRUE;
                $nearKey = $keyval;
                $nearValue = $att;
                break;
	       }
	    }
	    	
	    if ($haveIssue === TRUE)
	       return "<p><b>EASY CHART BUILDER SHORTCODE ERROR</b><lu><li>Check for misspelled parameters (case matters)</li><li>Check for new lines (all must reside on one long line)</li><li>Error near [" . $key . "], [" . $att . "]</li></lu><br/>For assistance, please visit <a>http://www.dyerware.com/main/products/easy-chart-builder</a></p>";
	       
        $chartConfig = shortcode_atts( array(
                'type' => 'horizbar',
                'width' => '200',
                'height' => '200',
                'title' => '',
                'groupnames' => 'Group 1,Group 2,Group 3',
                'groupcolors' => '0070C0,FFFF00,FF0000,00CC00,A3A3A3,007070,00FFFF,CC7000',
                'valuenames' => 'test1,test2,test3,test4,test5',
                'group1values' => '0,0,0',
                'group2values' => '0,0,0',
                'group3values' => '0,0,0',
                'group4values' => '0,0,0',
                'group5values' => '0,0,0',
                'group6values' => '0,0,0',
                'group7values' => '0,0,0',
                'group8values' => '0,0,0',
                'imagealtattr' => 'dyerware',
                'imagetitleattr' => '',
                'hidechartdata' => 'false',
                'chartcolor' => 'FFFFFF',
                'chartfadecolor' => 'DDDDDD',
                'datatablecss' => 'hentry easyChartDataTable',
                'imgstyle' => 'text-align:center;float:center;')
			    , $atts );


	    // Translate strings to numerics
	    array_walk($chartConfig, array($this, 'translateNumerics'));
	   
	    // Work some default SEO stuff for the user
	    if ($chartConfig['imagealtattr'] == '')
	       $chartConfig['imagealtattr'] = $chartConfig['title'];
	    if ($chartConfig['imagealtattr'] == '')
	       $chartConfig['imagealtattr'] = "dyerware";       
	       	       
	    $this->chartNum++;
		$chartDiv = 'easyChartDiv' . $this->chartNum;
		$chartImg = $chartDiv . '_img';
		$tableDiv = $chartDiv . '_data';

		if (function_exists('json_encode')) {
        	$json = json_encode($chartConfig);
        	$chartDiv = json_encode($chartDiv);
        	$chartImg = json_encode($chartImg);
        	$tableDiv = json_encode($tableDiv);
        } else {
			require_once('json_encode.php');
        	$json = Zend_Json_Encoder::encode($chartConfig);
        	$chartDiv = Zend_Json_Encoder::encode($chartDiv);
        	$tableDiv = Zend_Json_Encoder::encode($tableDiv);
        	$chartImg = Zend_Json_Encoder::encode($chartImg);
		}
			
					 	
	    if ($chartConfig['hidechartdata'] == false)
	        $dataShow = "<br/><br/><INPUT type='button' value='Show/Hide Table Data' onclick='wpEasyChartToggle("
	        .$tableDiv
	        .");' style='text-align:center;' align='center' ><br/><div class='easyChartBuilder' id="
	        .$tableDiv
	        ." style='text-align:center;display:none;' align='center'></div>";
	    else
	       $dataShow = "";
		

	
        return <<<ecbCode
<div id={$chartDiv} style='width:100%;'  style='text-align:center;' align='center'>
<img id={$chartImg} style='{$chartConfig['imgstyle']}' alt='{$chartConfig['imagealtattr']}' title='{$chartConfig['imagetitleattr']}'  align='center' border='0' />
{$dataShow}
</div>
<script type="text/javascript">
//<![CDATA[
wpEasyChart.wpNewChart({$chartDiv}, {$json});
function wpEasyChartToggle(id) {
    var e = document.getElementById(id);
    if(e.style.display == 'block')
        e.style.display = 'none';
    else
        e.style.display = 'block';
}
//]]>
</script>
ecbCode;
   }
}  

// Instantiate our class
$wpEasyCharts = new wpEasyCharts();

/**
 * Add filters and actions
 */

add_action('wp_head', array($wpEasyCharts, 'addCSS'));
add_action('wp_print_scripts', array($wpEasyCharts, 'output_scripts'));
add_shortcode('easychart',array($wpEasyCharts, 'process_shortcode'));
?>
